#ifndef NT2_INCLUDE_CONSTANTS_FACT_6_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FACT_6_HPP_INCLUDED

#include <nt2/constant/include/constants/fact_6.hpp>

#endif
